@@ -21,10 +21,12 @@ from neutron.conf.agent import common
 from neutron.plugins.ml2.drivers.openvswitch.agent.common import constants \
     as ovs_consts
 from neutron_taas.services.taas.agents.extensions import taas as taas_base
+import neutron_taas.services.taas.drivers.linux.ovs_constants \
+    as taas_ovs_consts
+import neutron_taas.services.taas.drivers.linux.ovs_utils as taas_ovs_utils
 from oslo_config import cfg
 from oslo_log import log as logging
-import ovs_constants as taas_ovs_consts
-import ovs_utils as taas_ovs_utils
+
 
 LOG = logging.getLogger(__name__)
 
@@ -54,6 +56,13 @@ class OvsTaasDriver(taas_base.TaasAgentDriver):
         # Setup key-value manager for ingress BCMC flows
         self.bcmc_kvm = taas_ovs_utils.key_value_mgr(4096)
 
+    def periodic_tasks(self, args=None):
+        #
+        # Regenerate the flow in br-tun's TAAS_SEND_FLOOD table
+        # to ensure all existing tunnel ports are included.
+        #
+        self.update_tunnel_flood_flow()
+
     def setup_ovs_bridges(self):
         #
         # br-int : Integration Bridge
@@ -439,8 +448,8 @@ class OvsTaasDriver(taas_base.TaasAgentDriver):
     def _create_ingress_bcmc_flow_action(self, taas_id_list, out_port_id):
         flow_action = "normal"
         for taas_id in taas_id_list:
-                flow_action += (",mod_vlan_vid:%d,output:%d" %
-                                (taas_id, out_port_id))
+            flow_action += (",mod_vlan_vid:%d,output:%d" %
+                            (taas_id, out_port_id))
 
         return flow_action
 
